API Documentation
=================


.. automodule:: pyramid_deform
   :members: includeme

Form view
---------

.. autoclass:: FormView
   :members: 

    .. automethod:: __call__

Other
-----

.. autoclass:: CSRFSchema
   :members:
